# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`dispatcher`](#dispatcher): Installs and sets up the AEM Dispatcher module on your system.

**Defined types**

* [`dispatcher::farm`](#dispatcherfarm): Installs and configures an AEM Dispatcher farm instance on your system.

**Data types**

* [`Dispatcher::Farm::AuthChecker`](#dispatcherfarmauthchecker): A hash of AuthChecker attributes.
Used to configure the `/auth_checker` parameter instance of a Farm.
* [`Dispatcher::Farm::Cache`](#dispatcherfarmcache): A hash of cache attributes.
Used to configure the `/cache` parameter instance of a Farm.
* [`Dispatcher::Farm::Filter`](#dispatcherfarmfilter): A hash of filter attributes.
Used to configure the `/filter` parameter instance of a Farm.
* [`Dispatcher::Farm::Filter::Pattern`](#dispatcherfarmfilterpattern): A hash of filter pattern attributes.
Used to configure confgure the different options for a filter parameter.
* [`Dispatcher::Farm::GlobRule`](#dispatcherfarmglobrule): A hash of glob rule attributes.
Used to configure glob rules for different Farm Cache sections.
* [`Dispatcher::Farm::Renderer`](#dispatcherfarmrenderer): A hash of renderer attributes.
Used to configure the `/renderer` parameter instance of a Farm.
* [`Dispatcher::Farm::SessionManagement`](#dispatcherfarmsessionmanagement): A hash of sessionmanagement attributes.
Used to configure the `/sessionmanagement` parameter of a Farm.
* [`Dispatcher::Farm::StatisticsCategory`](#dispatcherfarmstatisticscategory): A hash of Statistic attributes.
Used to configure the `/statistics` parameter instance of a Farm.
* [`Dispatcher::Farm::StickyConnection`](#dispatcherfarmstickyconnection): A hash of Statistic attributes.
Used to configure the `/statistics` parameter instance of a Farm.
* [`Dispatcher::Farm::VanityUrls`](#dispatcherfarmvanityurls): A hash of vanity url attributes.
Used to configure the `/vanith_url` parameter instance of a Farm.

## Classes

### dispatcher

When this class is declared with the default options, Puppet:
- Installs the specified dispatcher module into Apache modules directory
- Defines a Puppet apache module resource for the dispatcher.
- Defines a default set of Dispatcher configurations
- Loads all defined dispatcher farms
- Reloads the Apache service

#### Examples

##### 

```puppet
class { 'dispatcher' :
  module_file => '/path/to/module/file.so'
}
contain dispatcher
```

#### Parameters

The following parameters are available in the `dispatcher` class.

##### `module_file`

Data type: `Stdlib::Filesource`

Specifes the source location of the dispatcher module. This is the file that will be copied into the Apache module library path.

##### `decline_root`

Data type: `Boolean`

Sets the value for `DispatcherDeclineRoot`. Defaults to `true`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

##### `log_file`

Data type: `Stdlib::Absolutepath`

Sets the value for `DispatcherLog`. Defaults to `<Apache logroot>/dispatcher.log`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

##### `log_level`

Data type: `Enum['error', 'warn', 'info', 'debug', 'trace']`

Sets the value for `DispatcherLogLevel`. Defaults to `warn`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

##### `pass_error`

Data type: `Variant[Boolean, Pattern[/^[\d\-,]+$/]]`

Sets the value for `DispatcherPassError`. Defaults to `false`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

##### `use_processed_url`

Data type: `Boolean`

Sets the value for `DispatcherUseProcessedURL`. Defaults to `true`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

##### `farms`

Data type: `Array[String]`

A list of Dispatcher Farm names. If specified a `dispatcher::farm` defintion will be created for each name. Use hiera data to specify the remaining parameters.<br/>
For example, to configure a Dispatcher with two farms *author* and *publish*:
```puppet
class { 'dispatcher' :
  module_file => '/path/to/module/file.so',
  farms       => ['author', 'publish'],
}
contain dispatcher
```

Default value: []

##### `keep_alive_timeout`

Data type: `Optional[Integer[0]]`

If specified, sets the value for `DispatcherKeepAliveTimeout`. Default For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

Default value: `undef`

##### `no_cannon_url`

Data type: `Optional[Boolean]`

If specified, sets the value for `DispatcherNoCanonURL`. For details see the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/dispatcher-install.html#apache-web-server-configure-apache-web-server-for-dispatcher).

Default value: `undef`

##### `vhosts`

Data type: `Array[String]`

A list of Apache VirthalHosts names. If specified a then the necessary fragment to load the Dispatcher will be appended to that conf file. If the virtual host is not in the catalog, an error will occur.<br/>

The custom fragment that is added:

```
<IfModule disp_apache2.c>
  SetHandler dispatcher-handler
</IfModule>
```

For example, to load the Dispatcher module in the *default* Apache VirtualHost:
```puppet
class { 'dispatcher' :
  module_file => '/path/to/module/file.so',
  vhosts      => ['default'],
}
contain dispatcher
```

Default value: []

## Defined types

### dispatcher::farm

This will configure an AEM Dispatcher Farm instance on the node. Farms require a minimum set of configuation details to properly function. These are the `renderers`, `filters`, and `cache`.
The remainder of the paramers have provided, reasonable defaults.

#### Examples

##### 

```puppet
dispatcher::farm { 'publish' :
  renderers => [
    { hostname => 'localhost', port => 4503 },
  ],
  filters => [
    { allow => false,
      rank  => 1,
      url   => { regex => true, pattern => '.*' },
    },
  ],
  cache => {
    docroot => '/var/www/html',
    rules => [
      { rank => 1, glob => '*.html', allow => true },
    ],
    allowed_clients => [
      { rank => 1, glob => '*', allow => false },
      { rank => 2, glob => '127.0.0.1', allow => true },
    ],
  }
}
```

#### Parameters

The following parameters are available in the `dispatcher::farm` defined type.

##### `renderers`

Data type: `Array[Dispatcher::Farm::Renderer]`

Specifes an array of renderers that to which this Farm will dispatch requests. Used to create the */renders* directive. See the
`Dispatcher::Farm::Renderer` documentation for details on the parameter's structure.

Default value: lookup("dispatcher::farm::${name}::renderers", Array[Dispatcher::Farm::Renderer], 'deep')

##### `filters`

Data type: `Array[Dispatcher::Farm::Filter]`

Specifies an array of filters that will be applied to the incoming requests. Used to create the */filter* directive. See the
`Dispatcher::Farm::Filter` documentation for details on the parameter's structure.

Default value: lookup("dispatcher::farm::${name}::filters", Array[Dispatcher::Farm::Filter], 'deep')

##### `cache`

Data type: `Dispatcher::Farm::Cache`

Configures the */cache* directive for the farm. See the `Dispatcher::Farm::Cache` documentation for details on the parameter's structure.

Default value: lookup("dispatcher::farm::${name}::cache", Dispatcher::Farm::Cache, 'deep')

##### `ensure`

Data type: `Enum['absent', 'present']`

Specifies if the farm host is present or absent.

Default value: lookup("dispatcher::farm::${name}::ensure", Enum['absent', 'present'], 'first', 'present')

##### `priority`

Data type: `Integer[0]`

Defines the priority for this farm. The priority will impact the order the file farm is loaded by the dispatcher module, and therefore
has implications for host resolution and request processing. For more information see the Dispatcher farm documentation.

Default value: lookup("dispatcher::farm::${name}::priority", Integer[0], 'first', 0)

##### `virtualhosts`

Data type: `Array[String]`

Specifies the list of virtual hosts for which this farm will process requests. Used to create the */virtualhosts*
directive. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#identifying-virtual-hosts-virtualhosts)
for more details.

Default value: lookup("dispatcher::farm::${name}::virtualhosts", Array[String], 'deep', [$name])

##### `clientheaders`

Data type: `Array[String]`

Specifies the list of headers which will be passed through. Used to create the */clientheaders* directive. See the
[Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#specifying-the-http-headers-to-pass-through-clientheaders)
for more details.

Default value: lookup("dispatcher::farm::${name}::clientheaders", Array[String], 'deep', [])

##### `sessionmanagement`

Data type: `Optional[Dispatcher::Farm::SessionManagement]`

Configures the */sessionmanagement* directive for a farm, used for seecuring cache access. See the
`Dispatcher::Farm::SessionManagement` documentation for details on the parameter's structure.

Default value: lookup("dispatcher::farm::${name}::sessionmanagement", Optional[Dispatcher::Farm::SessionManagement], 'first', undef)

##### `vanity_urls`

Data type: `Optional[Dispatcher::Farm::VanityUrls]`

Configures the */vanity_urls* directive for a farm. See the `Dispatcher::Farm::VanityUrls` documentation for
details on the parameter's structure.

Default value: lookup("dispatcher::farm::${name}::vanity_urls", Optional[Dispatcher::Farm::VanityUrls], 'first', undef)

##### `propagate_synd_post`

Data type: `Boolean`

Sets the flag for the */propagateSyndPost* directive. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#forwarding-syndication-requests-propagatesyndpost)
for more details.

Default value: lookup("dispatcher::farm::${name}::propagate_synd_post", Boolean, 'first', false)

##### `auth_checker`

Data type: `Optional[Dispatcher::Farm::AuthChecker]`

Configures the */auth_checker* directive for a farm. See the `Dispatcher::Farm::AuthChecker` documentation for
more details.

Default value: lookup("dispatcher::farm::${name}::auth_checker", Optional[Dispatcher::Farm::AuthChecker], 'deep', undef)

##### `statistics_categories`

Data type: `Optional[Array[Dispatcher::Farm::StatisticsCategory]]`

Configures the */statistics* directive for a farm. See the `Dispatcher::Farm::StatisticsCategory` documentation for
more details.

Default value: lookup("dispatcher::farm::${name}::statistics_categories", Optional[Array[Dispatcher::Farm::StatisticsCategory]], 'deep', undef)

##### `sticky_connections`

Data type: `Optional[Dispatcher::Farm::StickyConnection]`

Configures either the */stickyConnectionsFor* or */stickyConnections* directive for a farm. See the
`Dispatcher::Farm::StickyConnection` documentation for more details.

Default value: lookup("dispatcher::farm::${name}::sticky_connections", Optional[Dispatcher::Farm::StickyConnection], 'deep', undef)

##### `health_check`

Data type: `Optional[String[1]]`

If specified, sets the */health_check* url for a farm. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#specifying-a-health-check-page)
for details on the directive's use.

Default value: lookup("dispatcher::farm::${name}::health_check", Optional[String[1]], 'first', undef)

##### `retry_delay`

Data type: `Optional[Integer[0]]`

If specified, sets the */retryDelay* directive for a farm. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#specifying-the-page-retry-delay)
for details on the directive's use.

Default value: lookup("dispatcher::farm::${name}::retry_delay", Optional[Integer[0]], 'first', undef)

##### `number_of_retries`

Data type: `Optional[Integer[0]]`

If specified, sets the */numberOfRetries* directive for a farm. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#configuring-the-number-of-retries)
for details on the directive's use.

Default value: lookup("dispatcher::farm::${name}::number_of_retries", Optional[Integer[0]], 'first', undef)

##### `unavailable_penalty`

Data type: `Optional[Integer[0]]`

If specified, sets the */unavailablePenalty* directive for a farm. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#reflecting-server-unavailability-in-dispatcher-statistics)
for details on the directive's use.

Default value: lookup("dispatcher::farm::${name}::unavailable_penalty", Optional[Integer[0]], 'first', undef)

##### `failover`

Data type: `Boolean`

If specified, sets the */failover* directive for a farm. See the [Dispatcher documentation](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#using-the-failover-mechanism)
for details on the directive's use.

Default value: lookup("dispatcher::farm::${name}::failover", Boolean, 'first', false)

##### `secure`

Data type: `Boolean`

If set to `true`, will enable a set of rules intended to secure this farm based on the the [Dispatcher Security Checklist](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/getting-started/security-checklist.html).

The following rules are applied when this flag is set.

This filter will defined and positioned first in the list, providing a default security filter:
```
  /0000 { /type "deny" /url '.*' }
```

These filters will be appended to the end of the filter list. Any user-defined filters will have a lower rank, and
therefore will be listed before these. The intent of these filters is to protect the system from inadvernt access to
code, crawling, or systems which should be secure in production.
```
  /9993 { /type "deny" /url "/crx/*" }
  /9994 { /type "deny" /url "/system/*" }
  /9995 { /type "deny" /url "/apps/*" }
  /9996 { /type "deny" /selectors '(feed|rss|pages|languages|blueprint|infinity|tidy|sysview|docview|query|[0-9-]+|jcr:content)' /extension '(json|xml|html|feed)' }
  /9997 { /type "deny" /method "GET" /query "debug=*" }
  /9998 { /type "deny" /method "GET" /query "wcmmode=*" }
  /9999 { /type "deny" /extension "jsp" }
```

A default deny rule for cache invalidation will be added; it is expected there will be additional user-defined value(s) for approved clients.
```
  /cache {
    ...
    /allowedClients {
      /0000 { /type "deny" /glob "*" }
    }
  }
```

Default value: lookup("dispatcher::farm::${name}::secure", Boolean, 'first', false)

## Data types

### Dispatcher::Farm::AuthChecker

AuthChecker attributes hash. This type is passed to a `dispatcher::farm` to confgure the *auth_checker* parameter. This will define the properties as specified in the Dispatcher documentation for [caching secured content](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/permissions-cache.html#configure-dispatcher-for-permission-sensitive-caching).

Parameters:
 - url:      `StdLib::Absolutepath`
 - filters:  `Array[Dispatcher::Farm::GlobRule]`
 - headers:  `Array[Dispatcher::Farm::GlobRule]`

Alias of `Struct[{
    url     => Stdlib::Absolutepath,
    filters => Array[Dispatcher::Farm::GlobRule],
    headers => Array[Dispatcher::Farm::GlobRule],
  }]`

### Dispatcher::Farm::Cache

The Cache attributes structure. This type is passed to a `dispatcher::farm` to confgure the *cache* parameter. This will define the properties as specified in the Dispatcher documentation for [caching content](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#configuring-the-dispatcher-cache-cache).

Parameters:
 - docroot:               `StdLib::Absolutepath`
 - rules:                 `Array[Dispatcher::Farm::GlobRule]`
 - allowed_clients:       `Array[Dispatcher::Farm::GlobRule]`
 - manage_docroot         `Boolean`
 - statfile               `Stdlib::Absolutepath`
 - serve_stale_on_error:  `Boolean`
 - allow_authorized       `Boolean`
 - statfileslevel         `Integer[0]`
 - invalidate             `Array[Dispatcher::Farm::GlobRule]`
 - invalidate_handler     `Stdlib::Absolutepath`
 - ignore_url_params      `Array[Dispatcher::Farm::GlobRule`
 - headers                `Array[String]`
 - mode                   `Stdlib::Filemode`
 - grace_period           `Integer[0]`
 - enable_ttl             `Boolean`

Alias of `Struct[{
    docroot                        => Stdlib::Absolutepath,
    rules                          => Array[Dispatcher::Farm::GlobRule],
    allowed_clients                => Array[Dispatcher::Farm::GlobRule],
    Optional[manage_docroot]       => Boolean,
    Optional[statfile]             => Stdlib::Absolutepath,
    Optional[serve_stale_on_error] => Boolean,
    Optional[allow_authorized]     => Boolean,
    Optional[statfileslevel]       => Integer[0],
    Optional[invalidate]           => Array[Dispatcher::Farm::GlobRule],
    Optional[invalidate_handler]   => Stdlib::Absolutepath,
    Optional[ignore_url_params]    => Array[Dispatcher::Farm::GlobRule],
    Optional[headers]              => Array[String],
    Optional[mode]                 => Stdlib::Filemode,
    Optional[grace_period]         => Integer[0],
    Optional[enable_ttl]           => Boolean,
  }]`

### Dispatcher::Farm::Filter

Filter attributes hash.
Filter attributes hash. This type is passed to a `dispatcher::farm` to confgure the *filter* parameter. This will define the properties as specified in the Dispatcher documentation for [granting access to content](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#configuring-access-to-content-filter).
Parameters:
 - rank:      `Integer[0]`
 - allow:     `Boolean`
 - url:       `Dispatcher::Farm::Filter::Pattern`
 - method:    `Dispatcher::Farm::Filter::Pattern`
 - query:     `Dispatcher::Farm::Filter::Pattern`
 - protocol:  `Dispatcher::Farm::Filter::Pattern`
 - path:      `Dispatcher::Farm::Filter::Pattern`
 - selectors: `Dispatcher::Farm::Filter::Pattern`
 - extension: `Dispatcher::Farm::Filter::Pattern`
 - suffix:    `Dispatcher::Farm::Filter::Pattern`

Alias of `Struct[{
    rank                => Integer[0],
    allow               => Boolean,
    Optional[url]       => Dispatcher::Farm::Filter::Pattern,
    Optional[method]    => Dispatcher::Farm::Filter::Pattern,
    Optional[query]     => Dispatcher::Farm::Filter::Pattern,
    Optional[protocol]  => Dispatcher::Farm::Filter::Pattern,
    Optional[path]      => Dispatcher::Farm::Filter::Pattern,
    Optional[selectors] => Dispatcher::Farm::Filter::Pattern,
    Optional[extension] => Dispatcher::Farm::Filter::Pattern,
    Optional[suffix]    => Dispatcher::Farm::Filter::Pattern,
  }]`

### Dispatcher::Farm::Filter::Pattern

This structure is used to configure an individual **filter** for use in the `Dispatcher::Farm::Filter` attributes.

Parameters:
 - regex:   `Boolean`
 - pattern: `String`

Alias of `Struct[{
    regex   => Boolean,
    pattern => String
  }]`

### Dispatcher::Farm::GlobRule

This structure represents a glob that can be used across many of the other struct types. It's used to enforce and standardize their parameters.

Parameters:
 - rank:  `Integer[0]`
 - glob:  `String`
 - allow: `Boolean`

Alias of `Struct[{
    rank  => Integer[0],
    glob  => String,
    allow => Boolean,
  }]`

### Dispatcher::Farm::Renderer

The Renderer attributes structure. This type is passed to a `dispatcher::farm` to confgure the *renders* parameter. This will define the properties as specified in the Dispatcher documentation for [defining page renderers](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#defining-page-renderers-renders).

Parameters:
 - hostname:        `Stdlib::Host:`
 - port:            `Stdlib::Port:`
 - timeout:         `Integer[0]:`
 - receive_timeout: `Integer[0]:`
 - ipv4:            `Boolean:`
 - secure:          `Boolean:`
 - always_resolve:  `Boolean:`

Alias of `Struct[{
    hostname                  => Stdlib::Host,
    port                      => Stdlib::Port,
    Optional[timeout]         => Integer[0],
    Optional[receive_timeout] => Integer[0],
    Optional[ipv4]            => Boolean,
    Optional[secure]          => Boolean,
    Optional[always_resolve]  => Boolean,
  }]`

### Dispatcher::Farm::SessionManagement

The Session Management attributes structure. This type is passed to a `dispatcher::farm` to confgure the *sessionmanagement* parameter. This will define the properties as specified in the Dispatcher documentation for [authentication session management](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#enabling-secure-sessions-sessionmanagement).

Parameters:
 - directory: `Stdlib::Absolutepath`
 - encode:    `String`
 - header:    `String`
 - timeout:   `Integer[0]`

Alias of `Struct[{
    directory         => Stdlib::Absolutepath,
    Optional[encode]  => String,
    Optional[header]  => String,
    Optional[timeout] => Integer[0],
  }]`

### Dispatcher::Farm::StatisticsCategory

The Statistics Category attributes structure. This type is passed to a `dispatcher::farm` to confgure the *statistics_categories* parameter. This will define the properties as specified in the Dispatcher documentation for [configuring the load balancer](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#configuring-load-balancing-statistics).

Parameters:
 - rank: `Integer[0]`
 - name: `String`
 - glob: `String`

Alias of `Struct[{
    rank => Integer[0],
    name => String,
    glob => String,
  }]`

### Dispatcher::Farm::StickyConnection

The SticyConnection attributes structure. This type is passed to a `dispatcher::farm` to confgure the *sticky_connections* parameter. This will define the properties as specified in the Dispatcher documentation for [creating sticky connections](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#identifying-a-sticky-connection-folder-stickyconnectionsfor). Which struct used will determine if `/stickyConnectionsFor` or `/stickyConnections` is created as a result.

`/stickyConnectionsFor` Parameters:
 - String[1]

`/stickyConnections` Parameters:
 - paths:     `Array[String]`
 - domain:    `String`
 - http_only: `Boolean`
 - secure:    `Boolean`

Alias of `Variant[String[1], Struct[
    {
      paths               => Array[String],
      Optional[domain]    => String,
      Optional[http_only] => Boolean,
      Optional[secure]    => Boolean,
    }
  ]]`

### Dispatcher::Farm::VanityUrls

The Vanity URL attributes structure. This type is passed to a `dispatcher::farm` to confgure the *vanity_urls* parameter. This will define the properties as specified in the Dispatcher documentation for [enabling access to Vanity URLs](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#enabling-access-to-vanity-urls-vanity-urls).

Parameters:
 - file:  `Stdlib::Absolutepath`
 - delay: `Integer[0]`

Alias of `Struct[{
    file  => Stdlib::Absolutepath,
    delay => Integer[0],
  }]`

