#
# Puppet Dispatcher Module - A module to manage AEM Dispatcher installations and configuration files.
#
# Copyright 2019 Adobe Inc
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# @summary A hash of vanity url attributes.
#   Used to configure the `/vanith_url` parameter instance of a Farm.
#
# The Vanity URL attributes structure. This type is passed to a `dispatcher::farm` to confgure the *vanity_urls* parameter. This will define the properties as specified in the Dispatcher documentation for [enabling access to Vanity URLs](https://docs.adobe.com/content/help/en/experience-manager-dispatcher/using/configuring/dispatcher-configuration.html#enabling-access-to-vanity-urls-vanity-urls).
#
# Parameters:
#  - file:  `Stdlib::Absolutepath`
#  - delay: `Integer[0]`
#
type Dispatcher::Farm::VanityUrls = Struct[
  {
    file  => Stdlib::Absolutepath,
    delay => Integer[0],
  }
]

